pub struct MistralEmbedProvider { /* private fields */ }Expand description
Embedding provider backed by the Mistral AI embeddings API.
Default model: mistral-embed (1024 dims). Mistral’s embedding endpoint
follows an OpenAI-compatible request/response shape.
Implementations
Sourceimpl MistralEmbedProvider
impl MistralEmbedProvider
Sourcepub fn new(api_key: impl Into<String>) -> Self
pub fn new(api_key: impl Into<String>) -> Self
Create a new Mistral provider with the default model (mistral-embed).
Sourcepub fn with_model(
api_key: impl Into<String>,
model: impl Into<String>,
dimensions: usize,
) -> Self
pub fn with_model( api_key: impl Into<String>, model: impl Into<String>, dimensions: usize, ) -> Self
Create with an explicit model and dimension override.
Sourcepub fn with_base_url(self, base_url: impl Into<String>) -> Self
pub fn with_base_url(self, base_url: impl Into<String>) -> Self
Override the API base URL.
Sourcepub fn build_payload(&self, texts: &[String]) -> Value
pub fn build_payload(&self, texts: &[String]) -> Value
Build the request payload for the Mistral embeddings API.