pub struct NomicEmbedProvider { /* private fields */ }Expand description
Embedding provider backed by the Nomic Atlas embeddings API.
Default model: nomic-embed-text-v1.5 (768 dims). The Nomic endpoint
accepts an array of texts under the texts key and responds with
{ "embeddings": [ [...], ... ] }.
Implementations
Sourceimpl NomicEmbedProvider
impl NomicEmbedProvider
Sourcepub fn new(api_key: impl Into<String>) -> Self
pub fn new(api_key: impl Into<String>) -> Self
Create a new Nomic provider with the default model (nomic-embed-text-v1.5).
Sourcepub fn with_model(
api_key: impl Into<String>,
model: impl Into<String>,
dimensions: usize,
) -> Self
pub fn with_model( api_key: impl Into<String>, model: impl Into<String>, dimensions: usize, ) -> Self
Create with an explicit model and dimension override.
Sourcepub fn with_task_type(self, task_type: impl Into<String>) -> Self
pub fn with_task_type(self, task_type: impl Into<String>) -> Self
Set the task_type (search_document, search_query, clustering, classification).
Sourcepub fn build_payload(&self, texts: &[String]) -> Value
pub fn build_payload(&self, texts: &[String]) -> Value
Build the request payload for the Nomic embeddings API.