pub struct RuleBasedExpander { /* private fields */ }Expand description
Rule-based query expander that uses a synonym map to generate alternative queries. Each word in the query is checked against the synonym map, and if a match is found, new queries are generated by replacing that word with each of its synonyms.
Implementations
Sourceimpl RuleBasedExpander
impl RuleBasedExpander