QueryExpander

Trait QueryExpander 

pub trait QueryExpander: Send + Sync {
    // Required method
    fn expand(&self, query: &str) -> Vec<String>;
}
Trait for expanding a query into multiple alternative queries. Implementations should always include the original query first in the results.

Required Methods

fn expand(&self, query: &str) -> Vec<String>

Expand a query into multiple alternative queries, including the original.

Implementors