pub trait QueryExpander: Send + Sync {
// Required method
fn expand(&self, query: &str) -> Vec<String>;
}Expand description
Trait for expanding a query into multiple alternative queries. Implementations should always include the original query first in the results.